@@ -14,8 +14,9 @@
 #include <QImage>
 #include <QString>
 
-#ifdef HAVE_ZXING
-#ifdef ZXING_USE_READBARCODE
+#if HAVE_ZXING
+#define ZX_USE_UTF8 1
+#if ZXING_USE_READBARCODE
 #include <ZXing/ReadBarcode.h>
 #else
 #include <ZXing/DecodeHints.h>
@@ -137,7 +138,7 @@ bool BarcodeDecoder::maybeBarcode(int width, int height, BarcodeDecoder::Barcode
     return isPlausibleSize(width, height, hint) && isPlausibleAspectRatio(width, height, hint);
 }
 
-#ifdef HAVE_ZXING
+#if HAVE_ZXING
 struct {
     BarcodeDecoder::BarcodeType type;
     ZXing::BarcodeFormat zxingType;
@@ -191,7 +192,7 @@ BarcodeDecoder::BarcodeType formatToType(ZXing::BarcodeFormat format)
     return BarcodeDecoder::None;
 }
 
-#ifdef ZXING_USE_READBARCODE
+#if ZXING_USE_READBARCODE
 static ZXing::ImageFormat zxingImageFormat(QImage::Format format)
 {
     switch (format) {
@@ -217,7 +218,7 @@ static ZXing::ImageFormat zxingImageFormat(QImage::Format format)
 
 static ZXing::Result zxingReadBarcode(const QImage &img, const ZXing::DecodeHints &hints)
 {
-    return ZXing::ReadBarcode({img.bits(), img.width(), img.height(), zxingImageFormat(img.format()), img.bytesPerLine()}, hints);
+    return ZXing::ReadBarcode({img.bits(), img.width(), img.height(), zxingImageFormat(img.format()), static_cast<int>(img.bytesPerLine())}, hints);
 }
 #endif
 
@@ -230,7 +231,7 @@ void BarcodeDecoder::decodeZxing(const QImage &img, BarcodeDecoder::BarcodeTypes
     hints.setPossibleFormats(typeToFormats(format));
 #endif
 
-#ifdef ZXING_USE_READBARCODE
+#if ZXING_USE_READBARCODE
     hints.setBinarizer(ZXing::Binarizer::FixedThreshold);
     hints.setIsPure((format & BarcodeDecoder::IgnoreAspectRatio) == 0);
 
@@ -244,6 +245,30 @@ void BarcodeDecoder::decodeZxing(const QImage &img, BarcodeDecoder::BarcodeTypes
 #endif
 
     if (res.isValid()) {
+#if ZXING_VERSION >= QT_VERSION_CHECK(1, 4, 0)
+        // detect content type
+        std::string zxUtf8Text;
+        if (res.contentType() == ZXing::ContentType::Text) {
+            result.contentType = Result::Any;
+            zxUtf8Text = res.text();
+            // check if the text is ASCII-only (in which case we allow access as byte array as well)
+            if (std::any_of(zxUtf8Text.begin(), zxUtf8Text.end(), [](unsigned char c) { return c > 0x7F; })) {
+                result.contentType &= ~Result::ByteArray;
+            }
+        } else {
+            result.contentType = Result::ByteArray;
+        }
+
+        // decode content
+        if (result.contentType & Result::ByteArray) {
+            QByteArray b;
+            b.resize(res.bytes().size());
+            std::copy(res.bytes().begin(), res.bytes().end(), b.begin());
+            result.content = b;
+        } else {
+            result.content = QString::fromStdString(zxUtf8Text);
+        }
+#else
         // detect content type
         result.contentType = Result::Any;
         if (std::any_of(res.text().begin(), res.text().end(), [](const auto c) { return c > 255; })) {
@@ -262,6 +287,7 @@ void BarcodeDecoder::decodeZxing(const QImage &img, BarcodeDecoder::BarcodeTypes
         } else {
             result.content = QString::fromStdWString(res.text());
         }
+#endif
         result.positive |= formatToType(res.format());
     } else {
         result.negative |= format;
@@ -293,7 +319,7 @@ void BarcodeDecoder::decodeIfNeeded(const QImage &img, BarcodeDecoder::BarcodeTy
     if (aspectRatio > PDF417_MIN_ASPECT && aspectRatio < PDF417_MAX_ASPECT && (hint  & PDF417) && (result.negative & hint & PDF417) != (hint & PDF417)) {
         auto normalizedImg = img;
         // newer ZXing versions handle rotated/flipped codes themselves correctly
-#ifndef ZXING_USE_READBARCODE
+#if !ZXING_USE_READBARCODE
         if (normalizedImg.width() < normalizedImg.height()) {
             QTransform tf;
             tf.rotate(-90);
@@ -302,7 +328,7 @@ void BarcodeDecoder::decodeIfNeeded(const QImage &img, BarcodeDecoder::BarcodeTy
 #endif
 
         decodeZxing(normalizedImg, PDF417, result);
-#ifndef ZXING_USE_READBARCODE
+#if !ZXING_USE_READBARCODE
         if (result.positive & PDF417) {
             return;
         }
