@@ -6,6 +6,7 @@
 
 #include "place.h"
 #include "datatypes_p.h"
+#include "locationutil.h"
 
 #include <cmath>
 
@@ -91,6 +92,11 @@ KITINERARY_MAKE_PROPERTY(Place, QString, telephone, setTelephone)
 KITINERARY_MAKE_PROPERTY(Place, QString, identifier, setIdentifier)
 KITINERARY_MAKE_OPERATOR(Place)
 
+QUrl Place::geoUri() const
+{
+    return LocationUtil::geoUri(*this);
+}
+
 
 class AirportPrivate : public PlacePrivate
 {
