@@ -54,3 +54,22 @@ function parseReservation(html, node) {
     res.underName.name = name[1];
     return res;
 }
+
+function parsePdfTicket(pdf, node, triggerNode)
+{
+    const page = pdf.pages[triggerNode.location];
+    var res = triggerNode.result[0];
+
+    const dep = page.textInRect(0.0, 0.15, 0.35, 0.3).match(/([\s\S]+)\nDÉPART À\n(\d\d:\d\d)/);
+    res.reservationFor.departureStation.name = dep[1];
+    res.reservationFor.departureTime = res.reservationFor.departureDay.substr(0, 11) + dep[2];
+
+    const arr = page.textInRect(0.35, 0.15, 0.65, 0.3).match(/([\s\S]+)\nARRIVÉE À\n(\d\d:\d\d)/);
+    res.reservationFor.arrivalStation.name = arr[1];
+    res.reservationFor.arrivalTime = res.reservationFor.departureDay.substr(0, 11) + arr[2];
+
+    const passenger = page.text.match(/PASSAGER\n(.*)\n/);
+    res.underName.name = passenger[1];
+
+    return res;
+}
