@@ -6,8 +6,6 @@
 
 #pragma once
 
-#include "kitinerary_export.h"
-
 class QChar;
 class QString;
 class QStringView;
@@ -17,10 +15,8 @@ namespace KItinerary {
 /** String normalization and comparison utilities. */
 namespace StringUtil
 {
-    /** Strips out diacritics and converts to case-folded form.
-     *  @internal only exported for unit tests
-     */
-    KITINERARY_EXPORT QString normalize(QStringView str);
+    /** Strips out diacritics and converts to case-folded form. */
+    QString normalize(QStringView str);
 
     /** Assuming both sides are describing the same thing, this tries to find the "better" string.
      *  That is, prefer the one that didn't lose casing/unicode/etc in previous processing.
@@ -29,9 +25,11 @@ namespace StringUtil
 
     /** Returns how much of the prefix of two given strings are equal, in
      *  relation to the longer of the two input strings.
-     *  @internal only exported for unit tests
      */
-    KITINERARY_EXPORT float prefixSimilarity(QStringView s1, QStringView s2);
+    float prefixSimilarity(QStringView s1, QStringView s2);
+
+    /** Cleans up extra white spaces and XML entities from @p s. */
+    QString clean(const QString &s);
 }
 
 }
